Package 'ompdetect'

Title: Example Configure Test for 'OpenMP'
Description: Best practices for cross-platform 'OpenMP' support in an R package. On most platforms, use the R-provided Make macros. On macOS, test the pre-set environment variables, the CRAN builder configuration, the R-provided Make macros (which may be set when using a custom toolchain that supports OpenMP), and the custom OpenMP installation path (when mixing a CRAN build of R with an incompatible Xcode version).
Authors: Ivan Krylov [aut, cre]
Maintainer: Ivan Krylov <[email protected]>
License: GPL (>= 2)
Version: 0.2-0
Built: 2026-05-09 09:25:03 UTC
Source: https://github.com/eddelbuettel/ompdetect

Help Index


Did we detect OpenMP on this system?

Description

Print and return whether OpenMP support was detected during configuration of this package. Additionally, show the various limits on the number of OpenMP threads.

Usage

ompdetect()
  omplimits()

Details

All the work is done during the package configuration.

Value

Invisible TRUE if OpenMP was detected during configuration, FALSE otherwise. Also emits a message with the result of the check.

References

“Writing R Extensions”, section 1.2.1.1, OpenMP support: https://cran.r-project.org/doc/manuals/R-exts.html#OpenMP-support.

Examples

ompdetect()
  omplimits()